pub trait AbstractNode:
Send
+ Sync
+ 'static {
// Required methods
fn endpoint(&self) -> &Endpoint;
fn shutdown(&self);
// Provided methods
fn rpc_addr(&self) -> Option<SocketAddr> { ... }
fn stats(&self) -> Result<BTreeMap<String, CounterStats>> { ... }
}Expand description
Trait that provides fields used by the rpc handler for the net and node requests.
Required Methods
Provided Methods
Sourcefn rpc_addr(&self) -> Option<SocketAddr>
fn rpc_addr(&self) -> Option<SocketAddr>
Rpc address of the node, used by the node status rpc call
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".